@@ -24,10 +24,10 @@ def deploy():
 def test():
     #sudo('rm -rf /srv/plug')
     put('*.plug', '/tmp')
-    sudo('plug install --plug=/tmp/plug-0.1.2.server1.plug')
-    sudo('plug setup --plug=plug-0.1.2.server1.plug')
-    #sudo('plug install --plug=/tmp/plug-0.1.2.server2.plug')
-    #sudo('plug setup --plug=plug-0.1.2.server2.plug')
+    sudo('plug install /tmp/plug-0.1.3.server1.plug')
+    sudo('plug setup plug-0.1.3.server1.plug')
+    #sudo('plug install --plug=/tmp/plug-0.1.3.server3.plug')
+    #sudo('plug setup --plug=plug-0.1.3.server3.plug')
     sudo('plug list')
     time.sleep(3)
     sudo('plug status')
